import{H as o,I as i,s}from"./index-e0440f6f.js";const a=o=>i("./wizard",{method:"post",body:JSON.stringify(o)}),n=i=>o(`./info?configuration=${i}`),t=o=>i(`./delete?configuration=${o}`,{method:"post"}),e=o=>s("compile",{configuration:o}),f=i=>o(`./manifest.json?configuration=${i}`);export{e as a,f as b,a as c,t as d,n as g};
