import{_ as e,n as s,a as d,y as l}from"./index-e0440f6f.js";import"./c.2cdbdbed.js";import"./c.9fbc2162.js";let o=class extends d{render(){return l`
      <esphome-process-dialog
        heading="Update All"
        .type=${"update-all"}
        @closed=${this._handleClose}
      ></esphome-process-dialog>
    `}_handleClose(){this.parentNode.removeChild(this)}};o=e([s("esphome-update-all-dialog")],o);
